@@ -1,4 +1,4 @@
-from optparse import make_option
+from __future__ import unicode_literals
 
 from django.core.management.base import BaseCommand, CommandError
 from pybb import util
